Learn R Programming

BFF (version 4.5.0)

BFF.object: BFF Object

Description

The BFF object is a class that contains the results of a Bayes Factor Function. The BFF object contains the following fields:

BFFthe object containing the log_bf (log Bayes factor values) and corresponding omega values
inputthe object containing the input values
log_bf_h1maximized Bayes factor in favor of the alternative, or the corresponding Bayes factor if an omega is supplied
omega_h1corresponding omega value for maximized Bayes factor in favor of the alternative, orthe corresponding omega for the Bayes factor if an omega is supplied
log_bf_h0minimized Bayes factor in favor of the null (for medium or large effect sizes, only returned if a specific omega is not set)
omega_h0corresponding omega value for minimized Bayes factor in favor of the null (for medium or large effect sizes, only returned if a specific omega is not set)
alternativealternative hypothesis used in calculations
omega_setwas an omega value provided?
rr value (default is 1 if not provided by user)
test_typetype of BFF test
generic_testFALSE

Arguments