f_test_BFF constructs BFFs based on the t test. BFFs depend on hyperparameters r and tau^2 which determine the shape and scale of the prior distributions which define the alternative hypotheses.
By setting r > 1, we use higher-order moments for replicated studies. Fractional moments are set with r > 1 and r not an integer.
All results are on the log scale.
Usage
f_test_BFF(
f_stat,
n,
df1,
df2,
omega = NULL,
omega_sequence = if (is.null(omega)) seq(0.01, 1, by = 0.01),
r = 1
)
Value
Returns an S3 object of class `BFF` (see `BFF.object` for details).
Arguments
f_stat
T statistic
n
sample size (if one sample test)
df1
sample size of group one for two sample test.
df2
sample size of group two for two sample test
omega
standardized effect size. For the f-test, this is often called Cohen's f (can be a single entry or a vector of values)
omega_sequence
sequence of standardized effect sizes. If no omega is provided, omega_sequence is set to be seq(0.01, 1, by = 0.01)
r
variable controlling dispersion of non-local priors. Default is 1. r must be >= 1