t_test_BFF constructs BFFs based on the t test. BFFs depend on hyperparameters r and tau^2 which determine the shape and scale of the prior distributions which define the alternative hypotheses. By setting r > 1, we use higher-order moments for replicated studies. Fractional moments are set with r > 1 and r not an integer. All results are on the log scale.
t_test_BFF(
t_stat,
n = NULL,
n1 = NULL,
n2 = NULL,
one_sample = FALSE,
alternative = "two.sided",
omega = NULL,
omega_sequence = if (is.null(omega)) seq(0.01, 1, by = 0.01),
r = 1
)Returns an S3 object of class `BFF` (see `BFF.object` for details).
t statistic
sample size (if one sample test)
sample size of group one for two sample test. Must be provided if one_sample = FALSE
sample size of group two for two sample test. Must be provided if one_sample = FALSE
is test one sided? Default is FALSE
the alternative. options are "two.sided" or "less" or "greater"
standardized effect size. For the t-test, this is often called Cohen's d (can be a single entry or a vector of values)
sequence of standardized effect sizes. If no omega is provided, omega_sequence is set to be seq(0.01, 1, by = 0.01)
variable controlling dispersion of non-local priors. Default is 1. r must be >= 1
tBFF = t_test_BFF(t_stat = 2.5, n = 50, one_sample = TRUE)
tBFF
plot(tBFF)
Run the code above in your browser using DataLab